/*
 * TechItem.java
 *
 * Created on June 10, 2005, 5:42 AM
 */

import java.util.*;

/**
 * This class is responcible for holding one item from a Outpost 2 tech list.
 * @author MD5 Tag : 2AEDF06823FDAF9405649D893EAB23F5
 */
public class TechItem
{
 
    /**
     * The name of the technology
     */    
    protected String name;
    /**
     * The unqiue id number of the technology
     */    
    protected String id;
    /**
     * The category the technology falls under
     */    
    protected String catagory;
    /**
     * A list of all required technologies
     */    
    protected ArrayList reqs;
    /**
     * A list of all technologies dependent on this one
     */    
    protected ArrayList depen;
    /**
     * The technology's finished descripion
     */    
    protected String desc;
    /**
     * The technology's "teaser" description
     */    
    protected String teaser;
    /**
     * The Eden cost for this technology
     */    
    protected String eCost;
    /**
     * The Plymouth cost for this technology
     */    
    protected String pCost;
    /**
     * The max number of scientists that can research the technology
     */    
    protected String numSci;
    /**
     * The lab at which this technology is researched
     *
     * 1:Basic
     * 2:Standard
     * 3:Advanced
     */    
    protected String lab;
    /**
     * A list of all changes the technology makes
     */    
    protected ArrayList action;
    /**
     * The description that is given to changed objects
     */    
    protected String actionDesc;
    
    
    /**
     * Creates a new instance of TechItem
     * @param f The teaser for the technology
     * @param g The Eden cost for the technology
     * @param h The Plymouth cost for the technolgy
     * @param i The max scientist number for the technology
     * @param j The lab of the technology
     * @param k The actions of the technology
     * @param l The action label of the technology
     * @param a The name of the Technology
     * @param b The id number of the technology
     * @param c The category of the technology
     * @param d The requirements of the technology
     * @param e The description of the technology
     */
    
    
    public TechItem (String a,String b,String c, ArrayList d,String e,String f,String g,
    String h,String i,String j,ArrayList k,String l)
    {
        name = a;
        id = b;
        catagory = c;
        reqs = d;
        depen = new ArrayList ();
        desc = e;
        teaser = f;
        eCost = g;
        pCost = h;
        numSci = i;
        lab = j;
        action = k;
        actionDesc = l;
    }
    
    
    /**
     * Alternate blank constructor, <B>not used yet</B>
     */    
    public TechItem ()
    {
        name = "None";
        id = "99999";
        catagory = "0";
        reqs = new ArrayList ();
        depen = new ArrayList ();
        desc = "None";        
        teaser = "None";
        eCost = "-1";
        pCost = "-1";
        numSci = "0";
        lab = "1";
        action = new ArrayList();
        actionDesc = "";
    }
    
    
    
    
    /**
     * This method returns an actual tech script which canbe used by Outpost 2.
     *
     * No changes are required to this script for functionality.
     * @return A complete copy of Outpost 2 script
     */    
    public String getScript ()
    {
        String script = ";" + id + "\n";
        
        script += "BEGIN_TECH \"" + name + "\" " + id + "\n";
        script += "    CATEGORY        " + catagory + "\n";
        script += "    DESCRIPTION     " + desc + "\n";
        script += "    TEASER          " + teaser + "\n";
        script += "    IMPROVE_DESC    \"" + actionDesc + "\"\n";
        script += "    EDEN_COST       " + eCost + "\n";
        script += "    PLYMOUTH_COST   " + pCost + "\n";
        script += "    MAX_SCIENTISTS  " + numSci + "\n";
        script += "    LAB             " + lab + "\n";
        for(int x = 0; x < action.size (); x ++)
            script += "    "                  + action.get (x) + "\n";
        
        script += "END_TECH\n";
        
        return script;
    }
    
    /**
     *
     * @return The name of the technology
     */    
    public String getName ()
    {
        return name;
    }
    
    /**
     *
     * @return The id number of the technology
     */    
    public String getID ()
    {
        return id;
    }
    
    /**
     *
     * @return The category for the technology
     */    
    public String getCategory ()
    {
        return catagory;
    }
    
    /**
     *
     * @return The discripiton of the technology
     */    
    public String getDesciption ()
    {
        return desc;
    }
    
    /**
     *
     * @return The teaser of the technology
     */    
    public String getTeaser ()
    {
        return teaser;
    }
    
    /**
     *
     * @return The upgrade label of the technology
     */    
    public String getEnhancementDescription ()
    {
        return actionDesc;
    }
    
    /**
     *
     * @return The Eden cost of the technology
     */    
    public String getEndenCost ()
    {
        return eCost;
    }
    
    /**
     *
     * @return The Plymouth cost of the technology
     */    
    public String getPlymouthCost ()
    {
        return pCost;
    }
    
    /**
     *
     * @return The max scientist number of the technology
     */    
    public String getNumScientists ()
    {
        return numSci;
    }
    
    /**
     *
     * @return The lab type of the technology
     *
     * 1:Basic
     * 2:Standard
     * 3:Advanced
     */    
    public String getLabType ()
    {
        return lab;
    }
    
    /**
     *
     * @return The requirements of the technology
     */    
    public ArrayList getRequirements ()
    {
        return reqs;
    }
    
    /**
     *
     * @return The dependents of the technology
     */    
    public ArrayList getDependents ()
    {
        return depen;
    }
    
    /**
     *
     * @return The actions of the technology
     */    
    public ArrayList getActions ()
    {
        return action;
    }
    
    public int hashCode()
    {
        return ((name.hashCode ()+id.hashCode ()+desc.hashCode ())/127)+numSci.hashCode ();
    }
    
    public boolean equals(Object obj)
    {
        TechItem d = (TechItem)obj;
        return d.hashCode () == this.hashCode ();
    }
    
    public String toString()
    {
        return name;
    }
    
}
